@@ -211,15 +211,13 @@ static MagickBooleanType DecodeImage(Image *image,const size_t compression,
 
   ssize_t
     i,
-    x;
+    x,
+    y;
 
   unsigned char
     *p,
     *q;
 
-  ssize_t
-    y;
-
   assert(image != (Image *) NULL);
   assert(image->signature == MagickCoreSignature);
   assert(pixels != (unsigned char *) NULL);
@@ -640,6 +638,8 @@ static Image *ReadBMPImage(const ImageInfo *image_info,ExceptionInfo *exception)
   assert(exception != (ExceptionInfo *) NULL);
   assert(exception->signature == MagickCoreSignature);
   image=AcquireImage(image_info,exception);
+  image->columns=0;
+  image->rows=0;
   status=OpenBlob(image_info,image,ReadBinaryBlobMode,exception);
   if (status == MagickFalse)
     {
@@ -1107,15 +1107,15 @@ static Image *ReadBMPImage(const ImageInfo *image_info,ExceptionInfo *exception)
     length=(size_t) bytes_per_line*image->rows;
     if ((MagickSizeType) (length/256) > blob_size)
       ThrowReaderException(CorruptImageError,"InsufficientImageDataInFile");
+    pixel_info=AcquireVirtualMemory(image->rows,
+      MagickMax(bytes_per_line,image->columns+1UL)*sizeof(*pixels));
+    if (pixel_info == (MemoryInfo *) NULL)
+      ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
+    pixels=(unsigned char *) GetVirtualMemoryBlob(pixel_info);
     if ((bmp_info.compression == BI_RGB) ||
         (bmp_info.compression == BI_BITFIELDS) ||
         (bmp_info.compression == BI_ALPHABITFIELDS))
       {
-        pixel_info=AcquireVirtualMemory(image->rows,
-          MagickMax(bytes_per_line,image->columns+256UL)*sizeof(*pixels));
-        if (pixel_info == (MemoryInfo *) NULL)
-          ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
-        pixels=(unsigned char *) GetVirtualMemoryBlob(pixel_info);
         if (image->debug != MagickFalse)
           (void) LogMagickEvent(CoderEvent,GetMagickModule(),
             "  Reading pixels (%.20g bytes)",(double) length);
@@ -1132,11 +1132,6 @@ static Image *ReadBMPImage(const ImageInfo *image_info,ExceptionInfo *exception)
         /*
           Convert run-length encoded raster pixels.
         */
-        pixel_info=AcquireVirtualMemory(image->rows,
-          MagickMax(bytes_per_line,image->columns+256UL)*sizeof(*pixels));
-        if (pixel_info == (MemoryInfo *) NULL)
-          ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
-        pixels=(unsigned char *) GetVirtualMemoryBlob(pixel_info);
         status=DecodeImage(image,bmp_info.compression,pixels,
           image->columns*image->rows);
         if (status == MagickFalse)
@@ -1570,8 +1565,8 @@ static Image *ReadBMPImage(const ImageInfo *image_info,ExceptionInfo *exception)
           unsigned short
             *p16;
 
-          p16=(unsigned short *) pixels+((ssize_t) image->rows-y-1)*
-            (ssize_t) bytes_per_line;
+          p16=(unsigned short *) (pixels+((ssize_t) image->rows-y-1)*
+            (ssize_t) bytes_per_line);
           q=QueueAuthenticPixels(image,0,y,image->columns,1,exception);
           if (q == (Quantum *) NULL)
             break;
@@ -1699,7 +1694,8 @@ static Image *ReadBMPImage(const ImageInfo *image_info,ExceptionInfo *exception)
           break;
       }
   } while (IsBMP(magick,2) != MagickFalse);
-  (void) CloseBlob(image);
+  if (CloseBlob(image) == MagickFalse)
+    status=MagickFalse;
   if (status == MagickFalse)
     return(DestroyImageList(image));
   return(GetFirstImageInList(image));
@@ -2661,6 +2657,7 @@ static MagickBooleanType WriteBMPImage(const ImageInfo *image_info,Image *image,
     if (status == MagickFalse)
       break;
   } while (image_info->adjoin != MagickFalse);
-  (void) CloseBlob(image);
-  return(MagickTrue);
+  if (CloseBlob(image) == MagickFalse)
+    status=MagickFalse;
+  return(status);
 }
